@@ -8,31 +8,18 @@ use strum::EnumString;
 
 #[derive(Parser)]
 pub struct LoggingArgs {
-    #[clap(
-    long, short,
-    parse(from_occurrences),
-    about = "\
-    Sets the log-level of rustube [default: Info]\n\
-    (-v = Error, ..., -vvvvv = Trace)\n\
-    (other crates have log level Warn)\n\
-    "
-    )]
+    /// Sets the log-level of rustube [default: Info]
+    /// (-v = Error, ..., -vvvvv = Trace)
+    /// (other crates have log level Warn)
+    #[clap(long, short, parse(from_occurrences))]
     verbose: u8,
 
-    #[clap(
-    long,
-    default_value = "always",
-    possible_values = & ["always", "never"],
-    value_name = "WHEN",
-    about = "When to log coloredd"
-    )]
+    /// When to log coloredd
+    #[clap(long, default_value = "always", possible_values = & ["always", "never"], value_name = "WHEN")]
     color: ColorUsage,
 
-    #[clap(
-    long, short,
-    conflicts_with = "verbose",
-    about = "Turn off logging for all crates",
-    )]
+    /// Turn off logging for all crates
+    #[clap(long, short, conflicts_with = "verbose")]
     quiet: bool,
 }
 
@@ -52,14 +39,17 @@ impl LoggingArgs {
     }
 
     fn log_msg_formatter(&self) -> fn(FormatCallback, &Arguments, &Record) {
-        macro_rules! msg_formatter {
-            ($out:ident, $message:ident, $log_level:expr) => {
-                $out.finish(format_args!(
-                    "{:<5}: {}",
-                    $log_level,
-                    $message
-                ))
-            };
+        #[inline(always)]
+        fn format_msg(
+            out: FormatCallback,
+            level: impl std::fmt::Display,
+            record: &Record,
+            msg: &Arguments,
+        ) {
+            out.finish(format_args!(
+                "{:<5} [{}:{}]: {}",
+                level, record.target(), record.line().unwrap_or_default(), msg,
+            ))
         }
 
         match self.color {
@@ -73,12 +63,22 @@ impl LoggingArgs {
                         trace: Color::White,
                     };
 
-                    msg_formatter!(out, message, COLORS.color(record.level()));
+                    format_msg(
+                        out,
+                        COLORS.color(record.level()),
+                        record,
+                        message,
+                    );
                 }
             }
             ColorUsage::Never => {
                 |out: FormatCallback, message: &Arguments, record: &Record| {
-                    msg_formatter!(out, message, record.level());
+                    format_msg(
+                        out,
+                        record.level(),
+                        record,
+                        message,
+                    );
                 }
             }
         }
